@@ -109,10 +109,10 @@ sub ParseUrlString {
 	my $name;
 	my $value;
 	if ($item =~ /^([^=]*)=(.*)$/) {
-	    $name = $1;
+	    $name = url_decode($1);
 	    $value = url_decode($2);
 	} else {
-	    $name = $item;
+	    $name = url_decode($item);
 	    $value = "";
 	}
 	if ($value ne "") {
@@ -656,16 +656,13 @@ sub quietly_check_login() {
     if (defined $::COOKIE{"Bugzilla_login"} &&
 	defined $::COOKIE{"Bugzilla_logincookie"}) {
         ConnectToDatabase();
-        if (!defined $ENV{'REMOTE_HOST'}) {
-            $ENV{'REMOTE_HOST'} = $ENV{'REMOTE_ADDR'};
-        }
         SendSQL("SELECT profiles.userid, profiles.groupset, " .
                 "profiles.login_name, " .
                 "profiles.login_name = " .
 		SqlQuote($::COOKIE{"Bugzilla_login"}) .
 		" AND profiles.cryptpassword = logincookies.cryptpassword " .
-		"AND logincookies.hostname = " .
-		SqlQuote($ENV{"REMOTE_HOST"}) .
+		" AND logincookies.ipaddr = " .
+		SqlQuote($ENV{"REMOTE_ADDR"}) .
                 ", profiles.disabledtext " .
 		" FROM profiles, logincookies WHERE logincookies.cookie = " .
 		SqlQuote($::COOKIE{"Bugzilla_logincookie"}) .
@@ -945,10 +942,7 @@ sub confirm_login {
      # the cookies.
      if($enteredlogin ne "") {
        $::COOKIE{"Bugzilla_login"} = $enteredlogin;
-       if (!defined $ENV{'REMOTE_HOST'}) {
-         $ENV{'REMOTE_HOST'} = $ENV{'REMOTE_ADDR'};
-       }
-       SendSQL("insert into logincookies (userid,cryptpassword,hostname) values (@{[DBNameToIdAndCheck($enteredlogin)]}, @{[SqlQuote($realcryptpwd)]}, @{[SqlQuote($ENV{'REMOTE_HOST'})]})");
+       SendSQL("insert into logincookies (userid,cryptpassword,ipaddr) values (@{[DBNameToIdAndCheck($enteredlogin)]}, @{[SqlQuote($realcryptpwd)]}, @{[SqlQuote($ENV{'REMOTE_ADDR'})]})");
        SendSQL("select LAST_INSERT_ID()");
        my $logincookie = FetchOneColumn();
 
