@@ -76,7 +76,7 @@ use RelationSet;
 delete $ENV{PATH};
 
 # Contains the version string for the current running Bugzilla.
-$::param{'version'} = '2.14.1';
+$::param{'version'} = '2.14.2';
 
 $::dontchange = "--do_not_change--";
 $::chooseone = "--Choose_one:--";
@@ -95,6 +95,19 @@ $::superusergroupset = "9223372036854775807";
 #}
 #$::SIG{__DIE__} = \&die_with_dignity;
 
+# Some files in the data directory must be world readable iff we don't have
+# a webserver group. Call this function to do this.
+sub ChmodDataFile($$) {
+	my ($file, $mask) = @_;
+	my $perm = 0770;
+	if ((stat('data'))[2] & 0002) {
+		$perm = 0777;
+	}
+	$perm = $perm & $mask;
+	chmod $perm,$file;
+}
+
+
 sub ConnectToDatabase {
     my ($useshadow) = (@_);
     if (!defined $::db) {
@@ -128,6 +141,9 @@ sub SyncAnyPendingShadowChanges {
                 return;
             } elsif (defined $pid) {
                 # child process code runs here
+                my $redir = ($^O =~ /MSWin32/i) ? "NUL" : "/dev/null";
+                open STDOUT,">$redir";
+                open STDERR,">$redir";
                 exec("./syncshadowdb","--") or die "Unable to exec syncshadowdb: $!";
                 # the idea was that passing the second parameter tricks it into
                 # using execvp instead of running a shell. Not really necessary since
@@ -519,8 +535,6 @@ sub GenerateVersionTable {
 
     my @list = sort { uc($a) cmp uc($b)} keys(%::versions);
     @::legal_product = @list;
-    mkdir("data", 0777);
-    chmod 0777, "data";
     my $tmpname = "data/versioncache.$$";
     open(FID, ">$tmpname") || die "Can't create $tmpname";
 
@@ -582,7 +596,7 @@ sub GenerateVersionTable {
     print FID "1;\n";
     close FID;
     rename $tmpname, "data/versioncache" || die "Can't rename $tmpname to versioncache";
-    chmod 0666, "data/versioncache";
+    ChmodDataFile('data/versioncache', 0666);
 }
 
 
@@ -1044,7 +1058,7 @@ sub GetLongDescriptionAsHTML {
         if ($count) {
             $result .= "<BR><BR><I>------- Additional Comments From ";
               if ($who) {
-                  $result .= qq{<A HREF="mailto:$email">$who</A> } .
+                  $result .= "<A HREF=\"mailto:$email\">" . html_quote($who) . "</A> " .
                       time2str("%Y-%m-%d %H:%M", str2time($when)) .
                           " -------</I><BR>\n";
               } else {
@@ -1121,8 +1135,10 @@ sub UserInGroup {
         return 0;
     }
     ConnectToDatabase();
+    PushGlobalSQLState();
     SendSQL("select (bit & $::usergroupset) != 0 from groups where name = " . SqlQuote($groupname));
     my $bit = FetchOneColumn();
+    PopGlobalSQLState();
     if ($bit) {
         return 1;
     }
@@ -1142,8 +1158,10 @@ sub BugInGroup {
 sub GroupExists {
     my ($groupname) = (@_);
     ConnectToDatabase();
+    PushGlobalSQLState();
     SendSQL("select count(*) from groups where name=" . SqlQuote($groupname));
     my $count = FetchOneColumn();
+    PopGlobalSQLState();
     return $count;
 }
 
@@ -1167,8 +1185,10 @@ sub GroupIsActive {
     my ($groupbit) = (@_);
     $groupbit ||= 0;
     ConnectToDatabase();
+    PushGlobalSQLState();
     SendSQL("select isactive from groups where bit=$groupbit");
     my $isactive = FetchOneColumn();
+    PopGlobalSQLState();
     return $isactive;
 }
 
